pub struct Ink { /* private fields */ }Expand description
An ink object.
Implementations
Sourceimpl Ink
impl Ink
Sourcepub fn ink_strokes(&self) -> &[InkStroke]
pub fn ink_strokes(&self) -> &[InkStroke]
The ink strokes contained in this ink object.
Sourcepub fn bounding_box(&self) -> Option<InkBoundingBox>
pub fn bounding_box(&self) -> Option<InkBoundingBox>
The ink object’s bounding box.
Sourcepub fn offset_horizontal(&self) -> Option<f32>
pub fn offset_horizontal(&self) -> Option<f32>
The horizontal offset from the page origin in half-inch increments.
See [MS-ONE] 2.3.18.
Sourcepub fn offset_vertical(&self) -> Option<f32>
pub fn offset_vertical(&self) -> Option<f32>
The vertical offset from the page origin in half-inch increments.
See [MS-ONE] 2.3.19.