pub struct Table { /* private fields */ }Expand description
A table.
See [MS-ONE] 2.2.26.
Implementations
Sourceimpl Table
impl Table
Sourcepub fn cols_locked(&self) -> &[u8] ⓘ
pub fn cols_locked(&self) -> &[u8] ⓘ
Which columns have a locked width.
To determine if column c has a locked width, calculate:
ⓘ
table.cols_locked()[c / 8] & (1 << (c % 8)) == 1;See [MS-ONE] 2.3.70.
Sourcepub fn col_widths(&self) -> &[f32]
pub fn col_widths(&self) -> &[f32]
The column widths in half-inch increments.
See [MS-ONE] 2.3.66.
Sourcepub fn borders_visible(&self) -> bool
pub fn borders_visible(&self) -> bool
Whether the table borders are visible.
See [MS-ONE] 2.3.65.
Sourcepub fn layout_alignment_in_parent(&self) -> Option<LayoutAlignment>
pub fn layout_alignment_in_parent(&self) -> Option<LayoutAlignment>
The table’s alignment relative to the containing outline element (if present).
See [MS-ONE] 2.3.27.
Sourcepub fn layout_alignment_self(&self) -> Option<LayoutAlignment>
pub fn layout_alignment_self(&self) -> Option<LayoutAlignment>
The table’s alignment.
See [MS-ONE] 2.3.33.
Note tags for this table.