Parser

Struct Parser 

pub struct Parser;
The OneNote file parser.

Use Parser::parse_notebook to load a notebook from a .onetoc2 file or Parser::parse_section to load a single .one section. These methods expect OneDrive downloads (FSSHTTP packaging) and will return an error if the input is not the expected file type.

Thread safety

The parser is stateless and can be shared across threads.

Implementations

Source

impl Parser

pub fn new() -> Parser

Create a new OneNote file parser.

The parser holds no state; reuse a single instance across multiple parses if desired.

pub fn parse_notebook(&self, path: &Path) -> Result<Notebook>

Parse a OneNote notebook.

The path argument must point to a .onetoc2 file. This will parse the table of contents of the notebook as well as all contained sections from the folder that the table of contents file is in.

Returns ErrorKind::NotATocFile if the file is not a notebook table of contents.

pub fn parse_section_buffer( &self, data: &[u8], file_name: &Path, ) -> Result<Section>

Parse a OneNote section buffer.

The data argument must contain a OneNote section. The file_name is used to populate section metadata and error messages.

Returns ErrorKind::NotASectionFile if the buffer does not contain a section file.

pub fn parse_section(&self, path: &Path) -> Result<Section>

Parse a OneNote section file.

The path argument must point to a .one file that contains a OneNote section.

Returns ErrorKind::NotASectionFile if the file does not contain a section.